@@ -44,6 +44,7 @@ from rasa.shared.constants import (
     UTTER_PREFIX,
 )
 from rasa.core.nlg import NaturalLanguageGenerator
+from rasa.core.lock_store import LockStore
 from rasa.core.policies.ensemble import PolicyEnsemble
 import rasa.core.tracker_store
 import rasa.shared.core.trackers
@@ -63,6 +64,7 @@ class MessageProcessor:
         policy_ensemble: PolicyEnsemble,
         domain: Domain,
         tracker_store: rasa.core.tracker_store.TrackerStore,
+        lock_store: LockStore,
         generator: NaturalLanguageGenerator,
         action_endpoint: Optional[EndpointConfig] = None,
         max_number_of_predictions: int = MAX_NUMBER_OF_PREDICTIONS,
@@ -74,6 +76,7 @@ class MessageProcessor:
         self.policy_ensemble = policy_ensemble
         self.domain = domain
         self.tracker_store = tracker_store
+        self.lock_store = lock_store
         self.max_number_of_predictions = max_number_of_predictions
         self.message_preprocessor = message_preprocessor
         self.on_circuit_break = on_circuit_break
@@ -418,24 +421,26 @@ class MessageProcessor:
         output_channel: OutputChannel,
     ) -> None:
         """Handle a reminder that is triggered asynchronously."""
-
-        tracker = await self.fetch_tracker_and_update_session(sender_id, output_channel)
-
-        if (
-            reminder_event.kill_on_user_message
-            and self._has_message_after_reminder(tracker, reminder_event)
-            or not self._is_reminder_still_valid(tracker, reminder_event)
-        ):
-            logger.debug(
-                f"Canceled reminder because it is outdated ({reminder_event})."
-            )
-        else:
-            intent = reminder_event.intent
-            entities = reminder_event.entities or {}
-            await self.trigger_external_user_uttered(
-                intent, entities, tracker, output_channel
+        async with self.lock_store.lock(sender_id):
+            tracker = await self.fetch_tracker_and_update_session(
+                sender_id, output_channel
             )
 
+            if (
+                reminder_event.kill_on_user_message
+                and self._has_message_after_reminder(tracker, reminder_event)
+                or not self._is_reminder_still_valid(tracker, reminder_event)
+            ):
+                logger.debug(
+                    f"Canceled reminder because it is outdated ({reminder_event})."
+                )
+            else:
+                intent = reminder_event.intent
+                entities = reminder_event.entities or {}
+                await self.trigger_external_user_uttered(
+                    intent, entities, tracker, output_channel
+                )
+
     async def trigger_external_user_uttered(
         self,
         intent_name: Text,
