@@ -54,7 +54,7 @@ def _guess_reader(
 
 
 async def load_data_from_resource(
-    resource: Union[Text, Path],
+    resource: Union[Text],
     domain: Domain,
     template_variables: Optional[Dict] = None,
     use_e2e: bool = False,
