@@ -21,6 +21,7 @@ from rasa.shared.nlu.constants import (
     ACTION_TEXT,
     ACTION_NAME,
 )
+from rasa.shared.constants import DIAGNOSTIC_DATA
 
 if typing.TYPE_CHECKING:
     from rasa.shared.nlu.training_data.features import Features
@@ -51,7 +52,30 @@ class Message:
         if features is not None:
             self.features.append(features)
 
-    def set(self, prop, info, add_to_output=False) -> None:
+    def add_diagnostic_data(self, origin: Text, data: Dict[Text, Any]) -> None:
+        """Adds diagnostic data from the `origin` component.
+
+        Args:
+            origin: Name of the component that created the data.
+            data: The diagnostic data.
+        """
+        if origin in self.get(DIAGNOSTIC_DATA, {}):
+            rasa.shared.utils.io.raise_warning(
+                f"Please make sure every pipeline component has a distinct name. "
+                f"The name '{origin}' appears at least twice and diagnostic "
+                f"data will be overwritten."
+            )
+        self.data.setdefault(DIAGNOSTIC_DATA, {})
+        self.data[DIAGNOSTIC_DATA][origin] = data
+
+    def set(self, prop: Text, info: Any, add_to_output: bool = False) -> None:
+        """Sets the message's property to the given value.
+
+        Args:
+            prop: Name of the property to be set.
+            info: Value to be assigned to that property.
+            add_to_output: Decides whether to add `prop` to the `output_properties`.
+        """
         self.data[prop] = info
         if add_to_output:
             self.output_properties.add(prop)
