@@ -93,6 +93,9 @@ TELEMETRY_VISUALIZATION_STARTED_EVENT = "Story Visualization Started"
 TELEMETRY_TEST_CORE_EVENT = "Model Core Tested"
 TELEMETRY_TEST_NLU_EVENT = "Model NLU Tested"
 
+# used to calculate the context on the first call and cache it afterwards
+TELEMETRY_CONTEXT = None
+
 
 def print_telemetry_reporting_info() -> None:
     """Print telemetry information to std out."""
@@ -461,7 +464,6 @@ def with_default_context_fields(
     return {**_default_context_fields(), **context}
 
 
-@functools.lru_cache()
 def _default_context_fields() -> Dict[Text, Any]:
     """Return a dictionary that contains the default context values.
 
@@ -470,17 +472,25 @@ def _default_context_fields() -> Dict[Text, Any]:
     """
     import tensorflow as tf
 
-    return {
-        "os": {"name": platform.system(), "version": platform.release()},
-        "ci": in_continuous_integration(),
-        "project": model.project_fingerprint(),
-        "directory": _hash_directory_path(os.getcwd()),
-        "python": sys.version.split(" ")[0],
-        "rasa_open_source": rasa.__version__,
-        "gpu": len(tf.config.list_physical_devices("GPU")),
-        "cpu": multiprocessing.cpu_count(),
-        "docker": _is_docker(),
-    }
+    global TELEMETRY_CONTEXT
+
+    if not TELEMETRY_CONTEXT:
+        TELEMETRY_CONTEXT = {
+            "os": {"name": platform.system(), "version": platform.release()},
+            "ci": in_continuous_integration(),
+            "project": model.project_fingerprint(),
+            "directory": _hash_directory_path(os.getcwd()),
+            "python": sys.version.split(" ")[0],
+            "rasa_open_source": rasa.__version__,
+            "gpu": len(tf.config.list_physical_devices("GPU")),
+            "cpu": multiprocessing.cpu_count(),
+            "docker": _is_docker(),
+        }
+
+    # avoid returning the cached dict --> caller could modify the dictionary...
+    # usually we would use `lru_cache`, but that doesn't return a dict copy and
+    # doesn't work on inner functions, so we need to roll our own caching...
+    return TELEMETRY_CONTEXT.copy()
 
 
 def _track(
@@ -705,7 +715,7 @@ async def track_model_training(
             "num_actions": len(domain.action_names_or_texts),
             # Old nomenclature from when 'responses' were still called
             # 'templates' in the domain
-            "num_templates": len(domain.templates),
+            "num_templates": len(domain.responses),
             "num_slots": len(domain.slots),
             "num_forms": len(domain.forms),
             "num_intents": len(domain.intents),
